=== modified file 'drizzled/filesort_info.h'
--- drizzled/filesort_info.h	2010-08-17 01:34:55 +0000
+++ drizzled/filesort_info.h	2010-08-18 03:47:58 +0000
@@ -36,6 +36,19 @@
   void    (*unpack)(struct sort_addon_field_st *, unsigned char *); /* To unpack back */
   unsigned char     *record_pointers;    /* If sorted in memory */
   ha_rows   found_records;      /* How many records in sort */
+
+  filesort_info_st() :
+    io_cache(0),
+    sort_keys(0),
+    buffpek(0),
+    buffpek_len(0),
+    addon_buf(0),
+    addon_length(0),
+    addon_field(0),
+    unpack(0),
+    record_pointers(0),
+    found_records()
+  { }
 };
 
 } /* namespace drizzled */

=== modified file 'drizzled/handler_structs.h'
--- drizzled/handler_structs.h	2010-08-10 05:18:35 +0000
+++ drizzled/handler_structs.h	2010-08-18 03:47:58 +0000
@@ -76,6 +76,17 @@
   uint32_t index_add_count;
   uint32_t *index_add_buffer;
   void *data;
+
+  st_ha_alter_information() :
+    key_info_buffer(0),
+    key_count(0),
+    index_drop_count(0),
+    index_drop_buffer(0),
+    index_add_count(0),
+    index_add_buffer(0),
+    data(0)
+  { }
+
 } HA_ALTER_INFO;
 
 

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2010-08-03 04:19:05 +0000
+++ drizzled/join.cc	2010-08-18 03:47:58 +0000
@@ -4409,10 +4409,11 @@
   join_tab->read_first_record= join_init_read_record;
   join_tab->join=join;
   join_tab->ref.key_parts= 0;
-  memset(&join_tab->read_record, 0, sizeof(join_tab->read_record));
+  join_tab->read_record.init();
   tmp_table->status=0;
   tmp_table->null_row=0;
-  return(false);
+
+  return false;
 }
 
 /**

=== modified file 'drizzled/memory/root.h'
--- drizzled/memory/root.h	2010-05-18 23:22:48 +0000
+++ drizzled/memory/root.h	2010-08-18 03:47:58 +0000
@@ -64,15 +64,25 @@
 {
 public:
 
-  Root() { }
+  Root() :
+    free(0),
+    used(0),
+    pre_alloc(0),
+    min_malloc(0),
+    block_size(0),
+    block_num(0),
+    first_block_usage(0),
+    error_handler(0)
+  { }
+
   Root(size_t block_size_arg)
   {
     free= used= pre_alloc= 0;
     min_malloc= 32;
     block_size= block_size_arg - memory::ROOT_MIN_BLOCK_SIZE;
-    error_handler= 0;
     block_num= 4;			/* We shift this with >>2 */
     first_block_usage= 0;
+    error_handler= 0;
   }
 
   /**
@@ -119,7 +129,6 @@
   }
   void free_root(myf MyFLAGS);
   void *multi_alloc_root(int unused, ...);
-
 };
 
 } /* namespace memory */

=== modified file 'drizzled/records.h'
--- drizzled/records.h	2010-06-03 22:43:14 +0000
+++ drizzled/records.h	2010-08-18 03:47:58 +0000
@@ -82,6 +82,34 @@
   {
   }
 
+  void init()
+  {
+    table= NULL;
+    cursor= NULL;
+    forms= 0;
+    read_record= 0;
+    session= 0;
+    select= 0;
+    cache_records= 0;
+    ref_length= 0;
+    struct_length= 0;
+    reclength= 0;
+    rec_cache_size= 0;
+    error_offset= 0;
+    index= 0;
+    ref_pos= 0;
+    record= 0;
+    rec_buf= 0;
+    cache= 0;
+    cache_pos= 0;
+    cache_end= 0;
+    read_positions= 0;
+    io_cache= 0;
+    print_error= 0;
+    ignore_not_found_rows= 0;
+    do_insideout_scan= 0;
+  }
+
   virtual ~ReadRecord()
   { }
 

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2010-08-17 01:34:55 +0000
+++ drizzled/sql_delete.cc	2010-08-18 03:47:58 +0000
@@ -80,7 +80,6 @@
     List<Item>   fields;
     List<Item>   all_fields;
 
-    memset(&tables, 0, sizeof(tables));
     tables.table = table;
     tables.alias = table_list->alias;
 

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-08-09 00:00:11 +0000
+++ drizzled/table.cc	2010-08-18 03:47:58 +0000
@@ -196,7 +196,6 @@
   memset(quick_n_ranges, 0, sizeof(unsigned int) * MAX_KEY);
 
   memory::init_sql_alloc(&mem_root, TABLE_ALLOC_BLOCK_SIZE, 0);
-  memset(&sort, 0, sizeof(filesort_info_st));
 }
 
 
@@ -1622,8 +1621,8 @@
   {						// Get keys for ni_create
     bool using_unique_constraint= false;
     HA_KEYSEG *seg= (HA_KEYSEG*) this->mem_root.alloc_root(sizeof(*seg) * keyinfo->key_parts);
-    if (!seg)
-      goto err;
+    if (not seg)
+      return true;
 
     memset(seg, 0, sizeof(*seg) * keyinfo->key_parts);
     if (keyinfo->key_length >= cursor->getEngine()->max_key_length() ||
@@ -1689,28 +1688,26 @@
     }
   }
   MI_CREATE_INFO create_info;
-  memset(&create_info, 0, sizeof(create_info));
 
   if ((options & (OPTION_BIG_TABLES | SELECT_SMALL_RESULT)) ==
       OPTION_BIG_TABLES)
     create_info.data_file_length= ~(uint64_t) 0;
 
-  if ((error=mi_create(share->getTableName(), share->sizeKeys(), &keydef,
-		       (uint32_t) (*recinfo-start_recinfo),
-		       start_recinfo,
-		       share->uniques, &uniquedef,
-		       &create_info,
-		       HA_CREATE_TMP_TABLE)))
+  if ((error= mi_create(share->getTableName(), share->sizeKeys(), &keydef,
+                        (uint32_t) (*recinfo-start_recinfo),
+                        start_recinfo,
+                        share->uniques, &uniquedef,
+                        &create_info,
+                        HA_CREATE_TMP_TABLE)))
   {
     print_error(error, MYF(0));
     db_stat= 0;
-    goto err;
+
+    return true;
   }
   in_use->status_var.created_tmp_disk_tables++;
   share->db_record_offset= 1;
   return false;
- err:
-  return true;
 }
 
 
@@ -1944,9 +1941,6 @@
 
   memset(quick_key_parts, 0, sizeof(unsigned int) * MAX_KEY);
   memset(quick_n_ranges, 0, sizeof(unsigned int) * MAX_KEY);
-
-  memset(&mem_root, 0, sizeof(memory::Root));
-  memset(&sort, 0, sizeof(filesort_info_st));
 }
 
 /*****************************************************************************

=== modified file 'plugin/myisam/myisam.h'
--- plugin/myisam/myisam.h	2010-06-07 06:04:12 +0000
+++ plugin/myisam/myisam.h	2010-08-18 03:47:58 +0000
@@ -162,6 +162,20 @@
   uint32_t old_options;
   uint8_t language;
   bool with_auto_increment;
+
+  st_mi_create_info():
+    index_file_name(0),
+    data_file_name(0),
+    max_rows(0),
+    reloc_rows(0),
+    auto_increment(0),
+    data_file_length(0),
+    key_file_length(0),
+    old_options(0),
+    language(0),
+    with_auto_increment(0)
+  { }
+
 } MI_CREATE_INFO;
 
 struct st_myisam_info;			/* For referense */

